<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config_dialog.ui" line="32"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="92"/>
        <source>Input mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="172"/>
        <source>Keymap style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="185"/>
        <location filename="config_dialog.ui" line="192"/>
        <source>Customize...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="218"/>
        <source>Basics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="899"/>
        <source>Privacy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="250"/>
        <source>Keymap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="199"/>
        <source>Romaji table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="272"/>
        <source>Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="294"/>
        <source>Adjust conversion based on previous input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="364"/>
        <source>Edit user dictionary...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="437"/>
        <source>Personalization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="501"/>
        <source>User dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="548"/>
        <source>Input Assistance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="580"/>
        <source>Fullwidth/Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="619"/>
        <source>Shift key mode switch</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="642"/>
        <source>、</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="675"/>
        <source>。</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="697"/>
        <source>Suggest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="776"/>
        <source>Maximum number of suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="837"/>
        <source>Clear all history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="857"/>
        <source>Clear unused history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="984"/>
        <source>Secret mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1035"/>
        <source>Temporarily disable conversion personalization, history-based suggestions and user dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1069"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1116"/>
        <source>Logging level (debug only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1145"/>
        <source>Logging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1177"/>
        <source>Administration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1063"/>
        <location filename="config_dialog.ui" line="1215"/>
        <source>Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1235"/>
        <source>Dictionary preloading and UAC settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="952"/>
        <source>Usage statistics and crash reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="57"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="99"/>
        <source>Punctuation style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="106"/>
        <source>Symbol style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="113"/>
        <source>Space input style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="123"/>
        <source>Selection shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="130"/>
        <source>Numpad style</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="147"/>
        <source>character entered by ¥ key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="287"/>
        <source>Clear personalization data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="383"/>
        <source>Single kanji dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="390"/>
        <source>Symbol dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="397"/>
        <source>Date/time conversion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="404"/>
        <source>Special number conversion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="411"/>
        <source>Emoticon dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="418"/>
        <source>Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="469"/>
        <source>Additional dictionaries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="523"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="612"/>
        <source>Automatically switch to halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="655"/>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="662"/>
        <source>Convert at punctuations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="688"/>
        <source>!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="698"/>
        <source>Always use Ja keyboard layout for Japanese input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="712"/>
        <source>Source data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="744"/>
        <source>Other settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="824"/>
        <source>Use input history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="844"/>
        <source>Use system dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="890"/>
        <source>Use realtime conversion (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="933"/>
        <source>Help make Mozc better by automatically sending usage statistics and crash reports to Google (changes will take effect after you log out and log back in)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1251"/>
        <source>Check if Mozc is the default IME on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1084"/>
        <source>Default IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1289"/>
        <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1325"/>
        <source>Reset to defaults</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.ui" line="14"/>
        <source>Mozc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.ui" line="62"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyBindingEditor</name>
    <message>
        <location filename="keybinding_editor.ui" line="32"/>
        <source>Mozc key binding editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keybinding_editor.ui" line="92"/>
        <source>Input key assignments:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="character_form_editor.cc" line="16"/>
        <location filename="character_form_editor.cc" line="31"/>
        <source>Fullwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="19"/>
        <location filename="character_form_editor.cc" line="33"/>
        <source>Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="22"/>
        <location filename="character_form_editor.cc" line="35"/>
        <source>Remember</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="25"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="44"/>
        <location filename="character_form_editor.cc" line="54"/>
        <location filename="character_form_editor.cc" line="124"/>
        <source>Katakana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="46"/>
        <location filename="character_form_editor.cc" line="57"/>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="48"/>
        <location filename="character_form_editor.cc" line="59"/>
        <source>Alphabets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::CharacterFormEditor</name>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Fullwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="69"/>
        <source>Remember</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="73"/>
        <source>Character form editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Composition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="91"/>
        <source>Conversion</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::ConfigDialog</name>
    <message>
        <location filename="config_dialog.cc" line="89"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="90"/>
        <source>MS-IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="91"/>
        <source>Kotoeri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="88"/>
        <source>Custom keymap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="93"/>
        <source>Romaji</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="94"/>
        <source>Kana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="98"/>
        <source>Romaji (switchable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="99"/>
        <source>Kana (switchable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="102"/>
        <location filename="config_dialog.cc" line="118"/>
        <source>Follow input mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="103"/>
        <location filename="config_dialog.cc" line="119"/>
        <source>Fullwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="104"/>
        <location filename="config_dialog.cc" line="120"/>
        <source>Halfwidth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="106"/>
        <source>No shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="107"/>
        <source>1 -- 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="108"/>
        <source>A -- L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="110"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="111"/>
        <source>Yes (don&apos;t record new data)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="112"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="114"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="115"/>
        <source>Alphanumeric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="116"/>
        <source>Katakana</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="121"/>
        <source>Direct input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="127"/>
        <source>Yen Sign Â¥</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="128"/>
        <source>Backslash \</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="219"/>
        <source>Dictionary preloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="332"/>
        <source>Romaji/Kana setting is enabled from new applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="601"/>
        <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="617"/>
        <source>Mozc Converter is not running. Settings were not saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="641"/>
        <source>Mozc Converter is not running. Settings were not saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="714"/>
        <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
 - Personalization data
 - Input history
 - Usage statistics and crash reports
 - Administrator settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="123"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="124"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="125"/>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="251"/>
        <location filename="config_dialog.cc" line="317"/>
        <location filename="config_dialog.cc" line="331"/>
        <location filename="config_dialog.cc" line="339"/>
        <location filename="config_dialog.cc" line="600"/>
        <location filename="config_dialog.cc" line="616"/>
        <location filename="config_dialog.cc" line="626"/>
        <location filename="config_dialog.cc" line="640"/>
        <location filename="config_dialog.cc" line="650"/>
        <location filename="config_dialog.cc" line="664"/>
        <location filename="config_dialog.cc" line="713"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="252"/>
        <source>Failed to get current config values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="318"/>
        <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="340"/>
        <source>Failed to update config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="665"/>
        <source>Mozc Converter is not running. operation was not executed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="627"/>
        <source>Do you want to clear all history data?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="651"/>
        <source>Do you want to clear unused history data?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.cc" line="60"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="128"/>
        <location filename="generic_table_editor.cc" line="173"/>
        <location filename="generic_table_editor.cc" line="184"/>
        <location filename="generic_table_editor.cc" line="206"/>
        <location filename="generic_table_editor.cc" line="214"/>
        <location filename="generic_table_editor.cc" line="222"/>
        <location filename="generic_table_editor.cc" line="243"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="129"/>
        <location filename="generic_table_editor.cc" line="174"/>
        <source>No entry is selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="185"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="197"/>
        <source>import from file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="207"/>
        <source>File not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="215"/>
        <source>The specified file is too large (&gt;=100K byte)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="223"/>
        <source>Import failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="234"/>
        <source>export to file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="244"/>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="277"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="278"/>
        <source>Remove entry</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::KeyMapEditorDialog</name>
    <message>
        <location filename="keymap_editor.cc" line="219"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="221"/>
        <source>Remove selected entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="225"/>
        <source>Import predefined mapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="229"/>
        <source>ATOK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="230"/>
        <source>MS-IME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="231"/>
        <source>Kotoeri</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="235"/>
        <source>Import from file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="237"/>
        <source>Export to file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="279"/>
        <source>Mozc keymap editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="283"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="283"/>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="283"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="367"/>
        <location filename="keymap_editor.cc" line="407"/>
        <location filename="keymap_editor.cc" line="426"/>
        <location filename="keymap_editor.cc" line="462"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="368"/>
        <source>Current keymap table is empty. You might want to import a pre-defined keymap table first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="408"/>
        <source>Invalid key:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="428"/>
        <source>The keymaps for IME ON and Reconversion will be applied after new applications.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="463"/>
        <source>Do you want to overwrite the current keymaps?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mozc::gui::RomanTableEditorDialog</name>
    <message>
        <location filename="roman_table_editor.cc" line="32"/>
        <source>New entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="34"/>
        <source>Remove selected entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="37"/>
        <source>Import from file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="39"/>
        <source>Export to file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="42"/>
        <source>Reset to defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="44"/>
        <source>Mozc Romaji table editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="48"/>
        <source>Next input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="127"/>
        <location filename="roman_table_editor.cc" line="149"/>
        <location filename="roman_table_editor.cc" line="189"/>
        <location filename="roman_table_editor.cc" line="216"/>
        <source>Mozc settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="128"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="150"/>
        <source>Romaji to Kana table is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="190"/>
        <source>Input fields contain capital characters. &quot;Shift-mode-switch&quot; function is disabled with this new mapping.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="217"/>
        <source>Do you want to overwrite the current roman table?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
